from datetime import datetime
class Acquisition:
    def __init__(self, target_company, acquiring_company, acquisition_ratio=None,price=None,leverage_ratio=None,date=None):
        self.target_company = target_company
        self.acquisition_ratio = acquisition_ratio
        self.acquiring_company = acquiring_company
        self.price = price
        self.leverage_ratio = leverage_ratio
        self.date = date

def main():
    print(666)
if __name__ == '__main__':
    main()