from cpanlp.entity.LLC import *
class SME(LLC):
    def __init__(self, name,type,capital):
        super().__init__(name,type,capital)
        self.public_accountability=False
def main():
    print(6)
if __name__ == '__main__':
    main()